## 基于 element-ui 的表单

参考地址 http://element.eleme.io/1.3/#/zh-CN/component/form

### 需求

| 组件名称 | 组件路径 | 组件说明
| --- | --- | --- |
| nftn-el-input | /components/element-ui/input.vue | 根据类型不同有不同的展示 |
| nftn-el-form | /components/element-ui/main.vue | 带有 grid 布局的表单组件 |

### 依赖
| 组件名称 | 组件路径 | 组件说明
| --- | --- | --- |
| nftn-el-grid | /components/element-ui/grid.vue | 配置自适应网格布局 |

### 图例
```viz
    digraph G {
        "nftn-el-form" -> "nftn-el-grid" -> "nftn-el-input";
        "nftn-el-input" -> text;
        "nftn-el-input" -> select;
        "nftn-el-input" -> datetimepicker;
        "nftn-el-input" -> "...";
    }
```

### 计划
---
#### @/components/element-ui/grid/main.vue ___(20170621)___
- [x] `v-bind:grid` 集成 grid 组件（按需创建 grid slots） ___(20170621√)___
- [x] `v-bind:label-position` ___(20170622√)___
- [x] `v-bind:label-width` ___(20170622√)___
- [x] `v-bind:action-grid` 表单操作放哪里？ ___(20170622 ~ 20170626√)___
- [x] `v-bind:inputs` 集成 input 组件 ___(20170622√)___
```javascript
let input = {
    grid: String, // √
    label: String, // √
    name: String, // √
    datasource: Array, // √
    disabled: Boolean(false), // √
    rules: Array, // √
    rows: Number, // √
    min: Number, // √ // type='checkbox'
    max: Number, // √ // type='checkbox | select'
    multiple: Boolean(false), // type='select' √
    clearable: Boolean(true) // type='select' √
};
```
- [x] `v-bind:rules` 集成 rules 组件 ___(20170622 ~ 20170626√)___
- [x] `v-model: Object` 集成 input 数据 ___(20170622√)___
- [x] 当 v-model 缺少数据时，自动补全 ___(20170622√)___
- [x] 添加 form.vue > grid 的 slot 接口 ___(20170626√)___
```html
<nftn-el-form>
    <template slot="grid-0-0">
        替换 grid-0-0 区域的内容，如果不存在这个区域，无效！
    </template>
<nftn-el-form>
```
- [x] 添加 form.vue > input 的 slot 接口 ___(20170626√)___
```html
<nftn-el-form>
    <template slot="inputname.label">
        替换 “inputname” 的label显示内容
    </template>
<nftn-el-form>
```
- [x] 添加 form.vue > grid 的 slot 接口 ___(20170626√)___
```html
<nftn-el-form>
    <template slot="inputname.input">
        替换 “inputname” 的输入显示内容
    </template>
<nftn-el-form>
```
---
#### @/components/element-ui/grid/input.vue ___(20170621)___
- [x] `v-bind:form-data => Object` 整个表单的数据，用以数据联动扩展 ___(20170627√)___
- [x] `v-bind:label => String` ___(20170622√)___
```mermaid
graph LR
    A[label:String] --> B{是否为空?};
    B --> |Y| C["不显示元素"]
    B --> |N| D["text + 空格（占个位）"]
```
- [x] `v-bind:type => String` ___(20170622√)___
- [x] `v-bind:name => String` ___(20170622√)___
- [x] `v-bind:configs => Object` ___(20170622√)___
- [x] `v-bind:datasource => Array` ___(20170622√)___
    ```javascript
    let datasource = [{
        name: String, // display label √
        value: String, // select value √
        disabled: Boolean(false) // is selectable? √
    }];
    ```
- [x] `v-model` ___(20170622√)___
- [x] `v-bind:disabled => Boolean(false)` ___(20170627√)___
- [x] 提供 label 的分发位置
- [x] 集成 input:text
    - [x] 基础模式   ___(20170621√)___
    - [ ] autocomplete 模式 ___(20170622 ~ ?)___
- [x] 集成 select
    - [x] 单选模式   ___(20170622 ~ 20170627√)___
    - [x] 多选模式`v-bind:multiple => Boolean(false)` ___(20170622 ~ 20170627√)___
    - [x] 多选数量限制 `v-bind:max => Number` ___(20170627√)___
    - [x] 选项可清除`v-bind:clearable => Boolean(true)`   ___(20170627√)___
    - [x] ~~自定义模版~~ ___(20170627 - !)___
    - [x] ~~分组~~ ___(20170627 - !)___
    - [ ] `v-bind:cascade => Object`
    ```javascript
    let cascade = {
        // 'direct', 'watch'
        mode: String, // (20170627)
        // 'self', 'formdata', 'window', 'remote'
        from: String,
        url: String, // only mode === 'remote' (20170627)
        key: String // (20170627)
    };
    ```
    - [ ] 主动级联 ___(20170627 ~ ?)___
    ```mermaid
    graph LR
        A[选中值] --> B[根据配置提取子数据];
        B --> C[分配数据到下级组件中];
    ```

    - [ ] 被动级联 ___(20170627 ~ ?)___

    ```mermaid
    graph LR
        A[侦听上级组件选中值] --> B[根据配置提取子数据];
        B --> C[在本组件中显示数据];
    ```

    - [ ] 远程级联 ___(20170627 ~ ?)___

    ```mermaid
    graph LR
        A[侦听上级组件选中值] --> B[根据配置获取远程数据];
        B --> C[在本组件中显示数据];
    ```

- [ ] 集成 datetimepicker ___(20170622 ~ ?)___
    - [ ] 日期模式   ___(20170622 ~ ?)___
    - [ ] 时间模式 ___(20170622 ~ ?)___
    - [ ] 日期+时间模式 ___(20170622 ~ ?)___
    - [ ] 日期范围模式 ___(20170622 ~ ?)___
    - [ ] 时间范围模式 ? ___(20170622 ~ ?)___
- [x] 集成 radio ___(20170622√)___
- [x] 集成 checkbox ___(20170622 ~ 20160627√)___
    - [x] `v-bind:min => Number` ___(20170627√)___
    - [x] `v-bind:max => Number` ___(20170627√)___
- [x] 集成 textarea ___(20170622 ~ 20170626√)___
    - [x] `v-bind:rows => Number` ___(20170626√)___
    - [x] ~~`v-bind:autosize => { minRows: Number, maxRows: Number }`~~ ___(20170626 - !)___
- [ ] 集成 upload ___(20170622 ~ ?)___
- [ ] 集成 switch ___(20170622 ~ ?)___
- [ ] 集成 slider ___(20170622 ~ ?)___
- [ ] 禁用依赖 `v-bind:disable-width => String,Array` ___(20170627 ~ ?)___
- [ ] 启用起来 `v-bind:enable-width => String,Array` ___(20170627 ~ ?)___
